#' @title Green birch leaf reflectance.
#'
#' @description A dataset of spectral reflectance expressed as a fraction of one.
#'
#' @details \itemize{ \item w.length (nm) \item Rfr (0..1) }
#'
#' @docType data
#' @keywords datasets
#' @format A \code{reflector_spct} object with 226 rows and 2 variables
#' @family Spectral data examples
#' @references
#' Aphalo, P. J. & Lehto, T. Effects of light quality on growth and N
#' accumulation in birch seedlings Tree Physiology, 1997, 17, 125-132
#'
#' @examples
#' green_leaf.spct
#'
"green_leaf.spct"
